==> fabric-orchestrator-client-0.0.6.tar.gz: fabric-orchestrator-client-0.0.6/fabric_cf/orchestrator/elements/constants.py <==
#!/usr/bin/env python3
# MIT License
#
# Copyright (c) 2020 FABRIC Testbed
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#
# Author: Komal Thareja (kthare10@renci.org)


class Constants:
    PROP_RESERVATIONS = 'reservations'
    PROP_SLICES = 'slices'
    PROP_SLICE_MODEL = 'slice_model'
    PROP_BQM_MODEL = "bqm"

    PROP_CAPACITIES = 'capacities'
    PROP_CAPACITY_ALLOCATIONS = 'capacity_allocations'
    PROP_LABELS = 'labels'
    PROP_LABEL_ALLOCATIONS = 'label_allocations'
    PROP_RESERVATION_INFO = 'reservation_info'
    PROP_SLIVER = 'sliver'

==> fabric-orchestrator-client-1.0b18.tar.gz: fabric-orchestrator-client-1.0b18/fabric_cf/orchestrator/elements/constants.py <==
#!/usr/bin/env python3
# MIT License
#
# Copyright (c) 2020 FABRIC Testbed
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#
# Author: Komal Thareja (kthare10@renci.org)


class Constants:
    PROP_RESERVATIONS = "reservations"
    PROP_SLICES = "slices"
    PROP_SLICE_MODEL = "slice_model"
    PROP_BQM_MODEL = "bqm"

    PROP_CAPACITIES = "capacities"
    PROP_LABELS = "labels"
    PROP_ALLOCATED_CAPACITIES = "allocated_capacities"
    PROP_ALLOCATED_LABELS = "allocated_labels"
    PROP_SLIVER_NAME = "name"
    PROP_MANAGEMENT_IP = "management_ip"
    PROP_CAPACITY_HINTS = "capacity_hints"

    PROP_STATE_ACTIVE = "Active"
